==> ghyp_0.8.3.tar.gz: ghyp/man/hist-methods.Rd <==
\name{hist.ghypuv}
\alias{hist.ghypuv}
\alias{hist-methods}
\alias{hist,ghypuv-method}
\title{Histogram for univariate generalized hyperbolic distributions}
\description{
  The generic function \code{hist.ghypuv} computes a histogram of the given data values
  and the univariate generalized hyperbolic density.
}
\usage{
\S4method{hist}{ghypuv}(
      x, data = ghyp.data(x), gaussian = TRUE, log = F, ylim = NULL, ghyp.col = 1, 
      ghyp.lwd = 1, ghyp.lty = "solid", col = 1, nclass = 30, legend = TRUE, 
      location = if (log) "bottom" else "topright", legend.cex = 1, ...)
}
\arguments{
  \item{x}{Usually a fitted univariate generalized hyperbolic distribution
           of class \code{\link[=mle.ghypuv-class]{mle.ghypuv}}. Alternatively
           an object of class \code{\link[=ghypuv-class]{ghypuv}} and a data vector.}
  \item{data}{A vector.}
  \item{gaussian}{If \code{TRUE} a qq-plot of the normal distribution is plotted as a reference.}
  \item{log}{If \code{TRUE} the logarithm of the histogramm is plotted.}
  \item{ylim}{The y limits of the plot.}
  \item{ghyp.col}{The color of the density of the generalized
                  hyperbolic distribution.}
  \item{ghyp.lwd}{The line width of the density of the generalized
                  hyperbolic distribution.}
  \item{ghyp.lty}{The line type of the density of the generalized
                  hyperbolic distribution.}
  \item{col}{The color of the histogramm.}
  \item{nclass}{A single number giving the number of cells for the histogramm.}
  \item{legend}{If \code{TRUE} a legend is drawn.}
  \item{location}{The location of the legend. See \code{\link{legend}} for possible values.}
  \item{legend.cex}{The character expansion of the legend.}
  \item{\dots}{Arguments passed to \code{\link{plot}} and  \code{\link{qqghyp}}.}

}
\value{
  No value returned
}
\author{David Lthi}
\seealso{\code{\link{qqghyp}}, \code{\link{fit.ghypuv}}, \code{\link{qghyp}}, \code{\link{plot}},
        \code{\link{hist}}, \code{\link{legend}}}
\examples{
  data(smi.stocks)
  univariate.fit <- fit.ghypuv(data=smi.stocks[,"SMI"],
                               opt.pars=c(mu=FALSE,sigma=FALSE),symmetric=T)
  hist(univariate.fit)
}
\keyword{distribution}
\keyword{models}
\keyword{hplot}
\keyword{methods}

==> ghyp_0.9.0.tar.gz: ghyp/man/hist-methods.Rd <==
\name{hist.ghypuv}
\alias{hist.ghypuv}
\alias{hist-methods}
\alias{hist,ghypuv-method}
\title{Histogram for univariate generalized hyperbolic distributions}
\description{
  The generic function \code{hist.ghypuv} computes a histogram of the given data values
  and the univariate generalized hyperbolic density.
}
\usage{
\S4method{hist}{ghypuv}(
      x, data = ghyp.data(x), gaussian = TRUE, log.hist = F, ylim = NULL, 
      ghyp.col = 1, ghyp.lwd = 1, ghyp.lty = "solid", col = 1, 
      nclass = 30, plot.legend = TRUE, 
      location = if (log) "bottom" else "topright", legend.cex = 1, ...)
}
\arguments{
  \item{x}{Usually a fitted univariate generalized hyperbolic distribution
           of class \code{\link[=mle.ghypuv-class]{mle.ghypuv}}. Alternatively
           an object of class \code{\link[=ghypuv-class]{ghypuv}} and a data vector.}
  \item{data}{A vector.}
  \item{gaussian}{If \code{TRUE} a qq-plot of the normal distribution is plotted as a reference.}
  \item{log.hist}{If \code{TRUE} the logarithm of the histogramm is plotted.}
  \item{ylim}{The y limits of the plot.}
  \item{ghyp.col}{The color of the density of the generalized
                  hyperbolic distribution.}
  \item{ghyp.lwd}{The line width of the density of the generalized
                  hyperbolic distribution.}
  \item{ghyp.lty}{The line type of the density of the generalized
                  hyperbolic distribution.}
  \item{col}{The color of the histogramm.}
  \item{nclass}{A single number giving the number of cells for the histogramm.}
  \item{plot.legend}{If \code{TRUE} a legend is drawn.}
  \item{location}{The location of the legend. See \code{\link{legend}} for possible values.}
  \item{legend.cex}{The character expansion of the legend.}
  \item{\dots}{Arguments passed to \code{\link{plot}} and  \code{\link{qqghyp}}.}

}
\value{
  No value returned
}
\author{David Lthi}
\seealso{\code{\link{qqghyp}}, \code{\link{fit.ghypuv}}, \code{\link{qghyp}}, \code{\link{plot}},
        \code{\link{hist}}, \code{\link{legend}}}
\examples{
  data(smi.stocks)
  univariate.fit <- fit.ghypuv(data=smi.stocks[,"SMI"],
                               opt.pars=c(mu=FALSE,sigma=FALSE),symmetric=T)
  hist(univariate.fit)
}
\keyword{hplot}
\keyword{methods}
